/*
 * Copyright 2005 Fluendo S.L.
 */
 /*********************************************************************
 * Adapted from dist10 reference code and used under the license therein:
 * ISO MPEG Audio Subgroup Software Simulation Group (1996)
 * ISO 13818-3 MPEG-2 Audio Decoder - Lower Sampling Frequency Extension
 **********************************************************************/
#ifndef __MP3TL_C_H__
#define __MP3TL_C_H__

typedef struct mp3cimpl_info mp3cimpl_info;

struct mp3cimpl_info {
  huffdec_bitbuf bb;          /* huffman decoder bit buffer */

  /* Hybrid */
  gdouble prevblck[2][SBLIMIT][SSLIMIT];

  /* scale data */
  guint scalefac_buffer[54];
};

void III_subband_synthesis (mp3tl *tl, frame_params *fr_ps, 
   gfloat hybridOut[SBLIMIT][SSLIMIT], gint channel, 
   short samples[SSLIMIT][SBLIMIT]);

#endif
